@@ -4,11 +4,11 @@ module HTML
       attr_reader :text
 
       def initialize(text, context = nil, result = nil)
-        raise TypeError, "text cannot be HTML" if text.is_a?(DocumentFragment)
+        raise TypeError, 'text cannot be HTML' if text.is_a?(DocumentFragment)
         # Ensure that this is always a string
         @text = text.respond_to?(:to_str) ? text.to_str : text.to_s
         super nil, context, result
       end
     end
   end
-end
\ No newline at end of file
+end
